@@ -8,9 +8,9 @@
 # <<< PARSE_ERROR: 'near "my ["' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ CRITICS ]]]
