@@ -7,9 +7,9 @@
 # <<< EXECUTE_SUCCESS: "have 2-D double dereference = 9" >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ CRITICS ]]]
