@@ -2,10 +2,10 @@
 # <<< PARSE_ERROR: 'ERROR ECOPARP00' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 package Perl::Types::Test::LiteralNumber::Package_47_Bad_03;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ CRITICS ]]]
