@@ -4,10 +4,10 @@
 # <<< PARSE_ERROR: 'syntax error' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 package Perl::Types::Test::Properties::Class_00_Bad_01;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ OO INHERITANCE ]]]
@@ -19,6 +19,6 @@ our properties
     = { empty_property => my integer $TYPED_empty_property = 2 };
 
 # [[[ SUBROUTINES & OO METHODS ]]]
-sub empty_method { { my integer::method $RETURN_TYPE }; return 2; }
+sub empty_method { { my integer $RETURN_TYPE }; return 2; }
 
 1;                  # end of class
