@@ -1,18 +1,18 @@
 # [[[ PREPROCESSOR ]]]
 # <<< PARSE_ERROR: 'ERROR ECOPAPL02' >>>
-# <<< PARSE_ERROR: 'near "( my number__arrayref"' >>>
+# <<< PARSE_ERROR: 'near "( my number:::arrayref"' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 package Perl::Types::Test::SubroutineArguments::Package_02_Bad;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ SUBROUTINES ]]]
 sub empty_sub {
     { my void $RETURN_TYPE };
-    ( my number__arrayref $foo ) = @ARG;
+    ( my number:::arrayref $foo ) = @ARG;
     return 1;
 }
 
