@@ -6,9 +6,9 @@
 # <<< PARSE_ERROR: 'Expected Token(s): VARIABLE_SYMBOL' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ CRITICS ]]]
