@@ -5,9 +5,9 @@
 # <<< PARSE_ERROR: 'Unexpected Token:  }' >>>
 
 # [[[ HEADER ]]]
-use Perl::Types;
 use strict;
 use warnings;
+use types;
 our $VERSION = 0.001_000;
 
 # [[[ CRITICS ]]]
